from picamera.array import PiRGBArray
from picamera import PiCamera
from threading import Thread
import cv2
import time

class PiVideoStream:
	def __init__(self, resolution=(320,240), framerate=32):
		self.camera = PiCamera(stereo_mode='side-by-side')
		self.camera.resolution = resolution
		self.camera.framerate = framerate
		self.rawCapture = PiRGBArray(self.camera, size=resolution)
		self.stream =self.camera.capture_continuous(self.rawCapture, format='bgr', use_video_port=True)
		
		self.frame = None
		self.stopped = False
		
	def start(self):
		Thread(target=self.update, args=()).start()
		return self
	
	def update(self):
		for f in self.stream:
			self.frame = f.array
			self.rawCapture.truncate(0)
			
			if self.stopped:
				self.stream.close()
				self.rawCapture.close()
				self.camera.close()
				return
	def read(self):
		return self.frame
		
	def stop(self):
		self.stopped = True
		
def main():
	vs = PiVideoStream().start()
	time.sleep(2.0)

	while True:
		frame = vs.read()
		print(f"frame size = {frame.shape}")
		cv2.imshow("Frame", frame)
		key = cv2.waitKey(1)
		
		if key & 0xFF == ord('q'):
			break

	cv2.destroyAllWindows()
	vs.stop()

if __name__ == '__main__':
	main()
